<?php
/*
Plugin Name: MyG2WP Converter
Plugin URI: http://www.deepwave.net/articles/myg2wp/
Description: MyGallery to WordPress Gallery Converter
Author: Patrick Khoo
Author URI: http://www.deepwave.net/
Version: 1.1
*/
/*
Introduction
Well, this plugin converts a MyGallery installation to use the
WordPress Gallery shortcodes and attachment system first introduced
in WP 2.5. However, this plugin has only been tested using WP 2.6 and
MyGallery 1.4b10.

This plugin is for advanced users, and even then, use at your own risk.

Installation
1. If you do not know how to install a plugin, maybe you should not be using
this plugin at all... Sorry...
2. Login to WordPress as Administrator, go to Plugins and Activate it.
3. Under the Plugins Menu, click on "MyG2WP Converter"
4. Follow the warnings and instructions on the screen

Note: If your MyGallery is not in the default myfotos folder, you may need to
edit the variable $DW_MYFOTOS_PATH below.

ChangeLog
Version: 1.1 - 2008-08-23
* Made location of myfotos folder a variable so that those who did not install
their myfotos into the default location can change it.
* Updated plugin to convert Description and Caption (alttitle) as well

Version: 1.0 - 2008-07-24
* Initial Release

Copyright (c) 2008 Patrick Khoo. All rights reserved.
*/

// Edit this Path if your photos are not in the MyGallery default folder of myfotos
$DW_MYFOTOS_PATH = '/wp-content/myfotos';

// Dont access directly
if ( !defined('ABSPATH') )
	die();

function DW_Converter_menu_add() {
	if ( function_exists('add_submenu_page') )
		add_submenu_page('plugins.php', 'MyG2WP Converter', 'MyG2WP Converter', 'level_10', 'myg2wpconv', 'DW_Converter_Menu');
}

function DW_Converter_menu() {
	$version = false;
	$success = false;

	// Introduction Page
	if (! isset($_POST['submit']) ) {
		DW_IntroPage();
		return true;
	}

	// There was a submit entry
	if ( function_exists('current_user_can') && !current_user_can('level_10') ) {
		die('Only the blog owner has permission to use this plugin.');
	}

	// Check Prerequisites
	if ( preg_match('/Check Prerequisites/', $_POST['submit']) ) {
		DW_VerCheckPage();
		return true;
	}

	// Confirmation Page
	if ( preg_match('/Next Step/', $_POST['submit']) ) {
		DW_ConfirmPage();
		return true;
	}

	// Really Do the Conversion
	if ( preg_match('/Begin Conversion/', $_POST['submit']) ) {
			DW_Converter_DoIt();
			?>
			<div class='wrap'>
				<h2>Conversion Completed</h2><br/>
				<div id="message" class="updated fade"><p><strong>
					Please print or save this page as a reference of the changes that were made.</strong> &nbsp; <a href="<?php bloginfo('url'); ?>/">View site &raquo;</a></p>
				</div>
				<p>
					Next steps:
					<ol>
						<li> Print/save this results page as a reference of the changes that were made
						<li> Check your blog to make sure it is working properly. If things go bad, restore from backup and review what went wrong before trying this again
						<li> Check/Edit all pages for layout/correct conversion etc
						<li> Disable/Delete this plugin
						<li> Disable/Delete MyGallery Plugin
						<li> You can remove the "mygallery", "mygprelation" and "mypictures" tables from your WordPress Database
						<li> You can remove the "tumbs" folder from each of your MyGallery gallery folders in the "myfotos" folder, but do not remove the "myfotos" folder or any of the gallery folders inside it, they have been added to the WordPress attachments system
					</ol>
				</p>
			</div>
			<?php
			return true;
	}

	// Hmm, some other command/option?
	DW_IntroPage();
	return true;
}

// ---------------------------------------------------------------------------------------------------------------------
function DW_IntroPage() {
	?>
	<div class="wrap">
		<h2>MyGallery To WordPress Gallery Converter</h2>
		<p style="padding: .2em; background-color: #DD2222; color: #FFFFFF; font-weight: bold; font-size: large; text-align: center;">
			W A R N I N G : &nbsp; Data may be lost permanently!
		</p>
		<p>
			If you are:
			<ul>
				<li> unclear about full backups/restores of WP Tables and All Files,
				<li> or are not really comfortable with thinking about mucking around with php or sql tables,
				<li> or are just not sure what to do and what this plugin is for,
				<li> or have no idea what I'm talking about . . .
			</ul>
			then please, do not use this plugin, because you may lose valuable data!
			This is a plugin for advanced and experienced WordPress users.<br/>
			<br/>
			This plugin will attempt to convert MyGallery installations and related shortcodes
			to the new WordPress Gallery attachments and shortcode system. The actual image files
			used by MyGallery are kept in the same place and merely added to WordPress. Please note that not
			all MyGallery shortcodes are converted, so some manual editing is still required. Also, the
			conversion is only performed on <u><strong>published</strong></u> posts - unpublished drafts, revisions, etc
			are ignored.<br/>
			<br/>
			This plugin will directly change WordPress tables, post data, and files in MyGallery.
			A full backup, ready to restore, is <u><strong>required</strong></u> - better still if you can try it first
			with on a "mirror" of your blog before actually doing it on the live one.<br/>
			<br/>
			After the conversion is complete, you will probably still have to go through your blog posts to verify
			if the layouts are correct. Some (many?) page layouts may need to be edited and changed because
			there are no exact matches between the layout options in MyGallery shortcodes and WordPress. So,
			after the conversion is complete, please print or save the results page as a reference of the changes
			that were made so that you know which pages/posts to check/edit.<br/>
			<br/>
			Also, due to the fact that WordPress attachments make use of parent/inherited posts as a way to associate
			posts with the attachments, the conversion process will associate attachments to the first matching
			published post. Therefore, having the same MyGallery gallery on multiple page will probably not convert
			properly. Watch out for "(Previously Added) Parent Post ID:" in the results to indicate that an attachment has
			been used more in more than one posts.
			<br/>
			Steps to take:
			<ol>
				<li> Upgrade your blog to WordPress 2.6
				<li> If you have to, disable your MyGallery plugin, but do not delete it or any of the files/tables, etc
				<li> Install and activate this plugin
				<li> Run this plugin and follow its instructions, the conversion process can take a long time to work, so please be patient!
				<li> Print/save the results page as a reference of the changes that were made
				<li> Once the conversion is complete, check your blog to make sure it is working properly. If things go bad, restore from backup and review what went wrong before trying this again
				<li> Check/Edit all pages for layout/correct conversion etc
				<li> Disable/Delete this plugin
				<li> Disable/Delete MyGallery Plugin
				<li> You can remove the "mygallery", "mygprelation" and "mypictures" tables from your WordPress Database
				<li> You can remove the "tumbs" folder from each of your MyGallery gallery folders in the "myfotos" folder, but do not remove the "myfotos" folder or any of the gallery folders inside it, they have been added to the WordPress attachments system
			</ol>
			<br/>
			<u><strong>All changes made by this plugin are irreversible - use this plugin at your own risk!</strong></u>
		</p>
		<form action="" method="post" id="myg2wpconv">
			<p class="submit"><input type="submit" name="submit" value="Check Prerequisites &raquo;"/></p>
		</form>
	</div>
	<?php
}

// ---------------------------------------------------------------------------------------------------------------------
function DW_VerCheckPage() {
	global $wpdb;  // Global WP DB Class
	$version = false;
	$mygaldet = false;
	$priorrun = false;
	$dw_mygprelation = $wpdb->prefix . 'mygprelation';  // Map between Gallery and Individual Pix

	// Check Blog Version
	if ( preg_match('/\\A(?:2\\.(6)\\.*.*)\\z/', get_bloginfo('version')) ) {
		$version = true;
	}
	// Check MyGallery Data
	if ($wpdb->get_row("SELECT * FROM $dw_mygprelation WHERE gid>0")) {
		$mygaldet = true;
	}
	// Check Prior Run
	if ($wpdb->get_row("SELECT * FROM $dw_mygprelation WHERE postid>0")) {
		$priorrun = true;
	}
	?>
	<div class="wrap">
		<h2>Check Prerequisites</h2>
		<?php if (! $version) { ?>
		<p style="padding: .2em; background-color: #DD2222; color: #FFFFFF; font-weight: bold; font-size: large; text-align: center;">
			W A R N I N G : &nbsp; WordPress version not supported!
		</p>
		<?php } ?>
		<?php if (! $mygaldet) { ?>
		<p style="padding: .2em; background-color: #DD2222; color: #FFFFFF; font-weight: bold; font-size: large; text-align: center;">
			W A R N I N G : &nbsp; MyGallery plugin data/tables missing/incomplete!
		</p>
		<?php } ?>
		<?php if ($priorrun) { ?>
		<p style="padding: .2em; background-color: #DD2222; color: #FFFFFF; font-weight: bold; font-size: large; text-align: center;">
			W A R N I N G : &nbsp; Tables have already been altered!<br/>(Are you trying to run this plugin more than once?)
		</p>
		<?php } ?>
		<p>
			This plugin has been developed and tested under WordPress 2.6 with MyGallery Plugin 1.4b10.
			There is no assurance that it will work in any other minor or major release of WordPress or MyGallery.<br/>
			<br/>
			If you are unsure, please do not continue.<br/>
		</p>
		<form action="" method="post" id="myg2wpconv">
			<p class="submit"><input type="submit" name="submit" value="Next Step &raquo;"/></p>
		</form>
	</div>
	<?php
}

// ---------------------------------------------------------------------------------------------------------------------
function DW_ConfirmPage() {
	?>
	<div class="wrap">
		<h2>Is That Your Final Answer?</h2>
		<p style="padding: .2em; background-color: #DD2222; color: #FFFFFF; font-weight: bold; font-size: large; text-align: center;">
			W A R N I N G : &nbsp; Are you sure?
		</p>
		<p>
			<u><strong>All changes made by this plugin are irreversible - use this plugin at your own risk!</strong></u><br/>
			<br/>
			Once you proceed to the next step, this plugin will begin to make real changes to your blog. 
			<strong><u>The conversion process can take a long time to work, so please be patient!</u></strong><br/>
			<br/>
			Reminder: After the conversion is complete, please print or save the results page as a reference of the changes that were made.
		</p>
		<form action="" method="post" id="myg2wpconv">
			<p class="submit"><input type="submit" name="submit" value="Begin Conversion &raquo;"/></p>
		</form>
	</div>
	<?php
}

// ---------------------------------------------------------------------------------------------------------------------
function DW_Converter_DoIt() {
	global $wpdb;  // Global WP DB Class
	global $DW_MYFOTOS_PATH;
   	$dw_mygallery = $wpdb->prefix . 'mygallery';  // Main Gallery DB
	$dw_mygprelation = $wpdb->prefix . 'mygprelation';  // Map between Gallery and Individual Pix
	$dw_mypictures = $wpdb->prefix . 'mypictures';  // Index of Pix
	$dw_TopPath = ABSPATH . $DW_MYFOTOS_PATH;
	$dw_TopURL = get_option('siteurl') . $DW_MYFOTOS_PATH;

	// ---- First, do we need to alter Table?
	if ($wpdb->get_row("SELECT * FROM $dw_mygprelation WHERE postid>0")) {
		// Table has already been altered!
		echo "<br/><div id='message' class='updated fade'><p><strong>W A R N I N G : &nbsp; Tables have already been altered! (Are you trying to run this plugin more than once?)</strong></p></div><br/>\n";
	} else {
		$wpdb->query("ALTER TABLE $dw_mygprelation ADD COLUMN postid BIGINT(20) UNSIGNED");
	}

	// ---- Go through all Images
	echo "<div class='wrap'>\n";
	echo "<h2>First Pass: Create Attachments From All Images</h2><br/>\n";
	$imgcount = 0;
	$imglist = $wpdb->get_results("SELECT * FROM $dw_mypictures LEFT JOIN $dw_mygprelation ON $dw_mypictures.id=$dw_mygprelation.pid LEFT JOIN $dw_mygallery ON $dw_mygprelation.gid=$dw_mygallery.id");
	foreach ($imglist as $aimg) {
		$imgcount++;
		$filedir = $dw_TopPath . '/' . $aimg->name;
		// Rename files to be "sanitized", for example, WordPress does not allow spaces in file names but MyG does..
		// Actually, we should use $filedir instead of $dw_TopPath, but wp_unique_filename() will create a unique
		// file name if the file already exists (and the file name is already sanitized), while on the other hand,
		// we only need wp_unique_filename() to sanitize the file name
		$filename = wp_unique_filename($dw_TopPath, $aimg->picturepath);
		$filepath = $filedir . '/' . $filename;
		if ((strcmp($filename, $aimg->picturepath) != 0) && (! file_exists($filepath))) {
			// File Name has been Sanitized and destination path does not already exist
			$origfilepath = $filedir . '/' . $aimg->picturepath;
			rename($origfilepath, $filepath);
		}
		// Have we added this attachment before?
		if ($aimg->postid>0) {
			echo "No $imgcount: PID: $aimg->pid, Path: <a href='$urlpath'>$aimg->name/$filename</a>, (Previously Added) AttachmentID: $aimg->postid<br/>\n";
			ob_flush(); flush();
			continue;
		}
		// Set Attachment Data
		$urlpath = $dw_TopURL . '/' . $aimg->name . '/' . $filename;
		$title = preg_replace('/\.[^.]+$/', '', $filename);
		$type = 'image/' . ltrim(strrchr($filename,'.'),'.');
		$description = '';
		$caption = '';
		if (strlen($aimg->description) > 0) {
			$description = $aimg->description;
		}
		echo "No $imgcount: PID: $aimg->pid, Path: <a href='$urlpath'>$aimg->name/$filename</a>";
		ob_flush(); flush();
		// Use image exif/iptc data for title and caption defaults if possible
		if ( $image_meta = @wp_read_image_metadata($filepath) ) {
			if ( trim($image_meta['title']) )
				$title = $image_meta['title'];
			if ( trim($image_meta['caption']) )
				$content = $image_meta['caption'];
		}
		// Insert Picture as Post Attachment
		$attachment = array(
			'post_title' => $title,
			'post_content' => $description,
			'post_status' => 'attachment',
			'post_parent' => 0,
			'post_mime_type' => $type,
			'guid' => $urlpath
			);
		$attach_id = wp_insert_attachment( $attachment, $filepath );
		if ( !is_wp_error($attach_id) ) {
			wp_update_attachment_metadata( $attach_id, wp_generate_attachment_metadata( $attach_id, $filepath ) );
			if (strlen($aimg->alttitle) > 0) {
				$attachment_update = array(
					'ID' => $attach_id,
					'post_excerpt' => $aimg->alttitle
					);
				//$attachment_update = get_post($attach_id, ARRAY_A);
				//$attachment_update['post_excerpt'] = $aimg->alttitle;
				wp_update_post($attachment_update);
			}
			if ($wpdb->query("UPDATE $dw_mygprelation SET postid=$attach_id WHERE pid=$aimg->pid") != 1) {
				echo ", AttachmentID: $attach_id - ERROR Updating Table!<br/>\n";
			} else {
				echo ", AttachmentID: $attach_id<br/>\n";
			}
		} else {
			echo ", Post Attach FAILED!<br/>\n";
		}
		ob_flush(); flush();
	}  // end foreach()
	echo "</div><br/>\n";

	// ---- Go through all posts looking for [myginpage=],[mygal=] tag
	echo "<div class='wrap'>\n";
	echo "<h2>Second Pass: Convert Galleries [myginpage=],[mygal=]</h2><br/>\n";
	$postlist = $wpdb->get_results("SELECT ID, post_title, post_content FROM $wpdb->posts WHERE post_status='publish' AND (post_content LIKE '%[myginpage=%' OR post_content LIKE '%[mygal=%')");
	$found = 0;
	foreach ($postlist as $apost) {
		echo "Post ID: $apost->ID, Title: <u>$apost->post_title</u><br/>\n";
		ob_flush(); flush();
		// [myginpage=]
		$search = "/\[myginpage=([A-Za-z0-9\-\_]+)(|\([0-9\,]+\))\]/";
		preg_match_all($search, $apost->post_content, $result);
		if (is_array($result)) {
			$found = 1;
			// $result[1] is Gallery Name, $result[2] is _IGNORED_ for conversion
			$arr_galname = $result[1];  $arr_res2 = $result[2];
			$galcount=count($arr_galname);
			for ($i = 0; $i < $galcount; $i++) {
				// Get Gallery ID
				$galdetails = $wpdb->get_row("SELECT * FROM $dw_mygallery WHERE name='$arr_galname[$i]'");
				echo " * GID: $galdetails->id, Gallery Name: $arr_galname[$i]<br/>\n";
				ob_flush(); flush();
				// Associate all pictures in this gallery with this post via attachment's post parent
				$galpics = $wpdb->get_results("SELECT * FROM $dw_mygprelation WHERE gid=$galdetails->id");
				foreach ($galpics as $apic) {
					DW_update_parent_post($apic->pid, $apost->ID, $apic->postid);
				}
				// Now replace [myginpage=] string in post
				$htmlstr = "[gallery]";
				$search = "[myginpage=$arr_galname[$i]"."$arr_res2[$i]]";
				if ($wpdb->query("UPDATE $wpdb->posts SET post_content=REPLACE(post_content, '$search', '$htmlstr') WHERE post_status='publish' AND post_content LIKE '%$search%'") > 0) {
					// Some Posts Updated!
					echo " &nbsp; &nbsp; - Post Content: Updated and SAVED!<br/>\n";
				} else {
					// Post Update Failed!
					echo " &nbsp; &nbsp; - Post Content: ERROR Updating Table!<br/>\n";
				}
				ob_flush(); flush();
			}  // end for()
		}  // end if()
		// [mygal=]
		$search = "/\[mygal=([A-Za-z0-9\-\_]+)(|\([0-9\,]+\))\]/";
		preg_match_all($search, $apost->post_content, $result);
		if (is_array($result)) {
			$found = 1;
			// $result[1] is Gallery Name, $result[2] is _IGNORED_ for conversion
			$arr_galname = $result[1];  $arr_res2 = $result[2];
			$galcount=count($arr_galname);
			for ($i = 0; $i < $galcount; $i++) {
				// Get Gallery ID
				$galdetails = $wpdb->get_row("SELECT * FROM $dw_mygallery WHERE name='$arr_galname[$i]'");
				echo " * GID: $galdetails->id, Gallery Name: $arr_galname[$i]<br/>\n";
				ob_flush(); flush();
				// Associate all pictures in this gallery with this post via attachment's post parent
				$galpics = $wpdb->get_results("SELECT * FROM $dw_mygprelation WHERE gid=$galdetails->id");
				foreach ($galpics as $apic) {
					DW_update_parent_post($apic->pid, $apost->ID, $apic->postid);
				}
				// Now replace [mygal=] string in post
				$htmlstr = "[gallery]";
				$search = "[mygal=$arr_galname[$i]"."$arr_res2[$i]]";
				if ($wpdb->query("UPDATE $wpdb->posts SET post_content=REPLACE(post_content, '$search', '$htmlstr') WHERE post_status='publish' AND post_content LIKE '%$search%'") > 0) {
					// Some Posts Updated!
					echo " &nbsp; &nbsp; - Post Content: Updated and SAVED!<br/>\n";
				} else {
					// Post Update Failed!
					echo " &nbsp; &nbsp; - Post Content: ERROR Updating Table!<br/>\n";
				}
				ob_flush(); flush();
			}  // end for()
		}  // end if()
		echo "<br/>\n";  // End of this post
	}  // end foreach()
	if (! $found) {
		echo "No Matching Posts Found!<br/>\n";
	}
	echo "</div><br/>";

	// ---- Go through all posts looking for [inspic=] tag
	echo "<div class='wrap'>\n";
	echo "<h2>Third Pass: Convert Individual Pictures [inspic=]</h2><br/>\n";
	$postlist = $wpdb->get_results("SELECT ID, post_title, post_content FROM $wpdb->posts WHERE post_status='publish' AND post_content LIKE '%[inspic=%'");
	$found = 0;
	foreach ($postlist as $apost) {
		echo "Post ID: $apost->ID, Title: <u>$apost->post_title</u><br/>\n";
		ob_flush(); flush();
		$search = "/\[inspic=(\d+)(|,\w+|,)(|,http:\/\/[^,]+|,fullscreen|,gal|,)(|,thumb|,\d+|,)(|,:\w+)\]/";
		preg_match_all($search, $apost->post_content, $result);
		if (is_array($result)) {
			$found = 1;
			// $result[1] is PID, $result[2] is align, [3] is popup option, [4] is scale or thumb, [5] is lightbox group
			$arr_pics = $result[1];  $arr_align = $result[2];  $arr_pop = $result[3];  $arr_size = $result[4];  $arr_lb = $result[5];
			$imgcount=count($arr_pics);
			for ($i = 0; $i < $imgcount; $i++) {
				// Find Attachment Post ID
				$apic = $arr_pics[$i];
				$attachpic = $wpdb->get_row("SELECT postid FROM $dw_mygprelation WHERE pid=$apic");
				if ($attachpic->postid>0) {
					// Handle Parent Post ID Assignment if Necessary
					DW_update_parent_post($apic, $apost->ID, $attachpic->postid);
					// Here, we have the Attachment Post ID, and settled the Parent Post ID
					// Now, convert the [inspic=] string into a WordPress HTML String and Save the Post
					// $align = 'none';
					$align = 'center';  // MyGallery Plugin's default alignment is actually "clear:both" (middle/center?)
					if (strpos($arr_align[$i],'left')) { $align='left'; }
					if (strpos($arr_align[$i],'right')) { $align='right'; }
					if (strpos($arr_pop[$i],'gal')) {
						$url = get_attachment_link($attachpic->postid);
						$rel = true;
					} else {
						$url = wp_get_attachment_url($attachpic->postid);
						$rel = false;
					}
					$size = 'medium';
					if (strpos($arr_size[$i],'thumb')) { $size='thumbnail'; }
					if ((is_int(ltrim($arr_size[$i],','))) && (0 == ltrim($arr_size[$i],','))) { $size='full'; }
					$htmlstr = get_image_send_to_editor($attachpic->postid, $alt, $title, $align, $url, $rel, $size);
					// $search = "/\[inspic=$arr_pics[$i]"."$arr_align[$i]"."$arr_pop[$i]"."$arr_size[$i]"."$arr_lb[$i]\]/";
					// $apost->post_content = preg_replace($search, $htmlstr, $apost->post_content);
					$search = "[inspic=$arr_pics[$i]"."$arr_align[$i]"."$arr_pop[$i]"."$arr_size[$i]"."$arr_lb[$i]]";
					// There is a concern that $htmlstr will contain ' character, which would make the query string fail,
					// but get_image_send_to_editor() should give good, clean HTML with " chars, right?
					if ($wpdb->query("UPDATE $wpdb->posts SET post_content=REPLACE(post_content, '$search', '$htmlstr') WHERE post_status='publish' AND post_content LIKE '%$search%'") > 0) {
						// Some Posts Updated!
						echo " &nbsp; &nbsp; - Post Content: Updated and SAVED!<br/>\n";
					} else {
						// Post Update Failed!
						echo " &nbsp; &nbsp; - Post Content: ERROR Updating Table!<br/>\n";
					}
				} else {
					echo " * PID: $apic, AttachmentID NOT FOUND!<br/>\n";
				}
				ob_flush(); flush();
			}  // end for()
		}
		echo "<br/>\n";  // End of this post
	}  // end foreach()
	if (! $found) {
		echo "No Matching Posts Found!<br/>\n";
	}
	echo "</div><br/>";

	// ---- Go through all posts looking for Unconverted MyGallery Plugin Shortcodes
	echo "<div class='wrap'>\n";
	echo "<h2>Fourth Pass: Search for Unconverted MyGallery Plugin Shortcodes [mypicref=],[mygallistgal]</h2><br/>\n";
	$postlist = $wpdb->get_results("SELECT ID, post_title, post_content FROM $wpdb->posts WHERE post_status='publish'");
	$found = 0;
	foreach ($postlist as $apost) {
		// [mypicref=]
		$search = "/\[mypicref=(\d+)\](.*)\[\/mypicref\]/U";
		if (preg_match($search, $apost->post_content)){
			$found = 1;
			echo "Post ID: $apost->ID, Title: <u>$apost->post_title</u> - FOUND: Picture Link [mypicref=]<br/>\n";
		}
		$search = "/\[mygallistgal\]/";
		if (preg_match($search, $apost->post_content)){
			$found = 1;
			echo "Post ID: $apost->ID, Title: <u>$apost->post_title</u> - FOUND: Gallery Overview [mygallistgal]<br/>\n";
		}
		ob_flush(); flush();
	}
	if (! $found) {
		echo "No Matching Posts Found!<br/>\n";
	}
	echo "</div><br/>";
	return true;
}

// ---------------------------------------------------------------------------------------------------------------------
function DW_update_parent_post($apic, $postid, $attachid) {
	global $wpdb;  // Global WP DB Class
	$attachdetails = $wpdb->get_row("SELECT post_parent FROM $wpdb->posts WHERE ID=$attachid");
	if ($attachdetails->post_parent<1) {
		// Set the post parent of this attachment to the current post
		if ($wpdb->query("UPDATE $wpdb->posts SET post_parent=$postid WHERE ID=$attachid AND post_parent=0") != 1) {
			echo " * PID: $apic, AttachmentID: $attachid, Parent Post ID: $postid - ERROR Updating Table!<br/>\n";
		} else {
			echo " * PID: $apic, AttachmentID: $attachid, Parent Post ID: $postid<br/>\n";
		}
	} else {
		echo " * PID: $apic, AttachmentID: $attachid, (Previously Added) Parent Post ID: $attachdetails->post_parent<br/>\n";
	}
	return true;
}


add_action('admin_menu', 'DW_Converter_menu_add');
?>